/****************************************************************************
** Meta object code from reading C++ file 'upowerbattery.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../solid-6.26.0/src/solid/devices/backends/upower/upowerbattery.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'upowerbattery.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Solid8Backends6UPower7BatteryE_t {};
} // unnamed namespace

template <> constexpr inline auto Solid::Backends::UPower::Battery::qt_create_metaobjectdata<qt_meta_tag_ZN5Solid8Backends6UPower7BatteryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Solid::Backends::UPower::Battery",
        "presentStateChanged",
        "",
        "newState",
        "udi",
        "chargePercentChanged",
        "value",
        "capacityChanged",
        "cycleCountChanged",
        "powerSupplyStateChanged",
        "chargeStateChanged",
        "timeToEmptyChanged",
        "time",
        "timeToFullChanged",
        "energyChanged",
        "energy",
        "energyFullChanged",
        "energyFull",
        "energyFullDesignChanged",
        "energyFullDesign",
        "energyRateChanged",
        "energyRate",
        "voltageChanged",
        "voltage",
        "temperatureChanged",
        "temperature",
        "remainingTimeChanged",
        "slotChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'presentStateChanged'
        QtMocHelpers::SignalData<void(bool, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'chargePercentChanged'
        QtMocHelpers::SignalData<void(int, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'chargePercentChanged'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'capacityChanged'
        QtMocHelpers::SignalData<void(int, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'cycleCountChanged'
        QtMocHelpers::SignalData<void(int, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'powerSupplyStateChanged'
        QtMocHelpers::SignalData<void(bool, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'chargeStateChanged'
        QtMocHelpers::SignalData<void(int, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'chargeStateChanged'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'timeToEmptyChanged'
        QtMocHelpers::SignalData<void(qlonglong, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 12 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'timeToFullChanged'
        QtMocHelpers::SignalData<void(qlonglong, const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 12 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'energyChanged'
        QtMocHelpers::SignalData<void(double, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 15 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'energyFullChanged'
        QtMocHelpers::SignalData<void(double, const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 17 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'energyFullDesignChanged'
        QtMocHelpers::SignalData<void(double, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 19 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'energyRateChanged'
        QtMocHelpers::SignalData<void(double, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 21 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'voltageChanged'
        QtMocHelpers::SignalData<void(double, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 23 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'temperatureChanged'
        QtMocHelpers::SignalData<void(double, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 25 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'remainingTimeChanged'
        QtMocHelpers::SignalData<void(qlonglong, const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 12 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'slotChanged'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Battery, qt_meta_tag_ZN5Solid8Backends6UPower7BatteryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Solid::Backends::UPower::Battery::staticMetaObject = { {
    QMetaObject::SuperData::link<DeviceInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends6UPower7BatteryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends6UPower7BatteryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Solid8Backends6UPower7BatteryE_t>.metaTypes,
    nullptr
} };

void Solid::Backends::UPower::Battery::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Battery *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->presentStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->chargePercentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->chargePercentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->capacityChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->cycleCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->powerSupplyStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->chargeStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->chargeStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->timeToEmptyChanged((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->timeToFullChanged((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->energyChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->energyFullChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->energyFullDesignChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->energyRateChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->voltageChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->temperatureChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->remainingTimeChanged((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->slotChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(bool , const QString & )>(_a, &Battery::presentStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(int , const QString & )>(_a, &Battery::chargePercentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(int , const QString & )>(_a, &Battery::capacityChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(int , const QString & )>(_a, &Battery::cycleCountChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(bool , const QString & )>(_a, &Battery::powerSupplyStateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(int , const QString & )>(_a, &Battery::chargeStateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(qlonglong , const QString & )>(_a, &Battery::timeToEmptyChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(qlonglong , const QString & )>(_a, &Battery::timeToFullChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(double , const QString & )>(_a, &Battery::energyChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(double , const QString & )>(_a, &Battery::energyFullChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(double , const QString & )>(_a, &Battery::energyFullDesignChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(double , const QString & )>(_a, &Battery::energyRateChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(double , const QString & )>(_a, &Battery::voltageChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(double , const QString & )>(_a, &Battery::temperatureChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Battery::*)(qlonglong , const QString & )>(_a, &Battery::remainingTimeChanged, 16))
            return;
    }
}

const QMetaObject *Solid::Backends::UPower::Battery::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Solid::Backends::UPower::Battery::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends6UPower7BatteryE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Solid::Ifaces::Battery"))
        return static_cast< Solid::Ifaces::Battery*>(this);
    if (!strcmp(_clname, "org.kde.Solid.Ifaces.Battery/0.3"))
        return static_cast< Solid::Ifaces::Battery*>(this);
    return DeviceInterface::qt_metacast(_clname);
}

int Solid::Backends::UPower::Battery::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DeviceInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void Solid::Backends::UPower::Battery::presentStateChanged(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Solid::Backends::UPower::Battery::chargePercentChanged(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 3
void Solid::Backends::UPower::Battery::capacityChanged(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Solid::Backends::UPower::Battery::cycleCountChanged(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void Solid::Backends::UPower::Battery::powerSupplyStateChanged(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Solid::Backends::UPower::Battery::chargeStateChanged(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 8
void Solid::Backends::UPower::Battery::timeToEmptyChanged(qlonglong _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void Solid::Backends::UPower::Battery::timeToFullChanged(qlonglong _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void Solid::Backends::UPower::Battery::energyChanged(double _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void Solid::Backends::UPower::Battery::energyFullChanged(double _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void Solid::Backends::UPower::Battery::energyFullDesignChanged(double _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void Solid::Backends::UPower::Battery::energyRateChanged(double _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void Solid::Backends::UPower::Battery::voltageChanged(double _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void Solid::Backends::UPower::Battery::temperatureChanged(double _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void Solid::Backends::UPower::Battery::remainingTimeChanged(qlonglong _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2);
}
QT_WARNING_POP
