// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_SOLID_BACKENDS_KDECONNECT_KDECONNECT_KDECONNECT_DEBUG_H
#define ECM_QLOGGINGCATEGORY_SOLID_BACKENDS_KDECONNECT_KDECONNECT_KDECONNECT_DEBUG_H

#include <QLoggingCategory>
 namespace Solid { namespace Backends { namespace KdeConnect {
Q_DECLARE_LOGGING_CATEGORY(KDECONNECT)
} } } 

#endif
