// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "udisks_debug.h"

 namespace Solid { namespace Backends { namespace UDisks2 {
Q_LOGGING_CATEGORY(UDISKS2, "kf.solid.backends.udisks2", QtWarningMsg)
} } } 
