// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "imobile_debug.h"

 namespace Solid { namespace Backends { namespace IMobile {
Q_LOGGING_CATEGORY(IMOBILE, "kf.solid.backends.imobile", QtWarningMsg)
} } } 
