// This file is autogenerated. Changes will be overwritten.
#include "CMNTTEQN7G/moc_kdeconnect_daemon_interface.cpp"
#include "CMNTTEQN7G/moc_kdeconnect_device_battery_interface.cpp"
#include "CMNTTEQN7G/moc_kdeconnect_device_interface.cpp"
