/****************************************************************************
** Meta object code from reading C++ file 'fakedevice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../solid-6.26.0/src/solid/devices/backends/fakehw/fakedevice.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fakedevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Solid8Backends4Fake10FakeDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto Solid::Backends::Fake::FakeDevice::qt_create_metaobjectdata<qt_meta_tag_ZN5Solid8Backends4Fake10FakeDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Solid::Backends::Fake::FakeDevice",
        "propertyChanged",
        "",
        "QMap<QString,int>",
        "changes",
        "conditionRaised",
        "condition",
        "reason",
        "udi",
        "parentUdi",
        "vendor",
        "product",
        "icon",
        "emblems",
        "description",
        "property",
        "QVariant",
        "key",
        "allProperties",
        "QMap<QString,QVariant>",
        "propertyExists",
        "setProperty",
        "value",
        "removeProperty",
        "lock",
        "unlock",
        "isLocked",
        "lockReason",
        "setBroken",
        "broken",
        "isBroken",
        "raiseCondition"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'propertyChanged'
        QtMocHelpers::SignalData<void(const QMap<QString,int> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'conditionRaised'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'udi'
        QtMocHelpers::SlotData<QString() const>(8, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'parentUdi'
        QtMocHelpers::SlotData<QString() const>(9, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'vendor'
        QtMocHelpers::SlotData<QString() const>(10, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'product'
        QtMocHelpers::SlotData<QString() const>(11, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'icon'
        QtMocHelpers::SlotData<QString() const>(12, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'emblems'
        QtMocHelpers::SlotData<QStringList() const>(13, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'description'
        QtMocHelpers::SlotData<QString() const>(14, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'property'
        QtMocHelpers::SlotData<QVariant(const QString &) const>(15, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'allProperties'
        QtMocHelpers::SlotData<QMap<QString,QVariant>() const>(18, 2, QMC::AccessPublic, 0x80000000 | 19),
        // Slot 'propertyExists'
        QtMocHelpers::SlotData<bool(const QString &) const>(20, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'setProperty'
        QtMocHelpers::SlotData<bool(const QString &, const QVariant &)>(21, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 17 }, { 0x80000000 | 16, 22 },
        }}),
        // Slot 'removeProperty'
        QtMocHelpers::SlotData<bool(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'lock'
        QtMocHelpers::SlotData<bool(const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'unlock'
        QtMocHelpers::SlotData<bool()>(25, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isLocked'
        QtMocHelpers::SlotData<bool() const>(26, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'lockReason'
        QtMocHelpers::SlotData<QString() const>(27, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setBroken'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'isBroken'
        QtMocHelpers::SlotData<bool()>(30, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'raiseCondition'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FakeDevice, qt_meta_tag_ZN5Solid8Backends4Fake10FakeDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Solid::Backends::Fake::FakeDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<Solid::Ifaces::Device::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends4Fake10FakeDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends4Fake10FakeDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Solid8Backends4Fake10FakeDeviceE_t>.metaTypes,
    nullptr
} };

void Solid::Backends::Fake::FakeDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FakeDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->propertyChanged((*reinterpret_cast<std::add_pointer_t<QMap<QString,int>>>(_a[1]))); break;
        case 1: _t->conditionRaised((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: { QString _r = _t->udi();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->parentUdi();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->vendor();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->product();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->icon();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->emblems();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->description();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QVariant _r = _t->property((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 10: { QMap<QString,QVariant> _r = _t->allProperties();
            if (_a[0]) *reinterpret_cast<QMap<QString,QVariant>*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->propertyExists((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->setProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->removeProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->lock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->unlock();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->isLocked();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->lockReason();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->setBroken((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: { bool _r = _t->isBroken();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->raiseCondition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FakeDevice::*)(const QMap<QString,int> & )>(_a, &FakeDevice::propertyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FakeDevice::*)(const QString & , const QString & )>(_a, &FakeDevice::conditionRaised, 1))
            return;
    }
}

const QMetaObject *Solid::Backends::Fake::FakeDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Solid::Backends::Fake::FakeDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends4Fake10FakeDeviceE_t>.strings))
        return static_cast<void*>(this);
    return Solid::Ifaces::Device::qt_metacast(_clname);
}

int Solid::Backends::Fake::FakeDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Solid::Ifaces::Device::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void Solid::Backends::Fake::FakeDevice::propertyChanged(const QMap<QString,int> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Solid::Backends::Fake::FakeDevice::conditionRaised(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
