/****************************************************************************
** Meta object code from reading C++ file 'kdeconnect_daemon_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../solid-6.26.0/src/solid/devices/backends/kdeconnect/dbus/kdeconnect_daemon_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kdeconnect_daemon_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN31OrgKdeKdeconnectDaemonInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeKdeconnectDaemonInterface::qt_create_metaobjectdata<qt_meta_tag_ZN31OrgKdeKdeconnectDaemonInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeKdeconnectDaemonInterface",
        "announcedNameChanged",
        "",
        "announcedName",
        "customDevicesChanged",
        "customDevices",
        "deviceAdded",
        "id",
        "deviceListChanged",
        "deviceRemoved",
        "deviceVisibilityChanged",
        "isVisible",
        "linkProvidersChanged",
        "linkProviders",
        "pairingRequestsChanged",
        "QDBusPendingReply<QString>",
        "deviceIdByName",
        "name",
        "deviceNames",
        "QDBusPendingReply<QMap<QString,QString>>",
        "onlyReachable",
        "onlyPaired",
        "devices",
        "QDBusPendingReply<QStringList>",
        "forceOnNetworkChange",
        "QDBusPendingReply<>",
        "selfId",
        "sendSimpleNotification",
        "eventId",
        "title",
        "text",
        "iconName",
        "setAnnouncedName",
        "setLinkProviderState",
        "linkProvider",
        "enabled",
        "pairingRequests"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'announcedNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'customDevicesChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 5 },
        }}),
        // Signal 'deviceAdded'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'deviceListChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'deviceVisibilityChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Bool, 11 },
        }}),
        // Signal 'linkProvidersChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 13 },
        }}),
        // Signal 'pairingRequestsChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'announcedName'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(3, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'deviceIdByName'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(16, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'deviceNames'
        QtMocHelpers::SlotData<QDBusPendingReply<QMap<QString,QString>>()>(18, 2, QMC::AccessPublic, 0x80000000 | 19),
        // Slot 'deviceNames'
        QtMocHelpers::SlotData<QDBusPendingReply<QMap<QString,QString>>(bool)>(18, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'deviceNames'
        QtMocHelpers::SlotData<QDBusPendingReply<QMap<QString,QString>>(bool, bool)>(18, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::Bool, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'devices'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(22, 2, QMC::AccessPublic, 0x80000000 | 23),
        // Slot 'devices'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(bool)>(22, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'devices'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(bool, bool)>(22, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Bool, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'forceOnNetworkChange'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(24, 2, QMC::AccessPublic, 0x80000000 | 25),
        // Slot 'linkProviders'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(13, 2, QMC::AccessPublic, 0x80000000 | 23),
        // Slot 'selfId'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(26, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'sendSimpleNotification'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, const QString &)>(27, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 29 }, { QMetaType::QString, 30 }, { QMetaType::QString, 31 },
        }}),
        // Slot 'setAnnouncedName'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(32, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'setLinkProviderState'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool)>(33, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 34 }, { QMetaType::Bool, 35 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'customDevices'
        QtMocHelpers::PropertyData<QStringList>(5, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'pairingRequests'
        QtMocHelpers::PropertyData<QStringList>(36, QMetaType::QStringList, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeKdeconnectDaemonInterface, qt_meta_tag_ZN31OrgKdeKdeconnectDaemonInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeKdeconnectDaemonInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31OrgKdeKdeconnectDaemonInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31OrgKdeKdeconnectDaemonInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31OrgKdeKdeconnectDaemonInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeKdeconnectDaemonInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeKdeconnectDaemonInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->announcedNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->customDevicesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->deviceListChanged(); break;
        case 4: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->deviceVisibilityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->linkProvidersChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 7: _t->pairingRequestsChanged(); break;
        case 8: { QDBusPendingReply<QString> _r = _t->announcedName();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<QString> _r = _t->deviceIdByName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<QMap<QString,QString>> _r = _t->deviceNames();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QMap<QString,QString>>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<QMap<QString,QString>> _r = _t->deviceNames((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QMap<QString,QString>>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<QMap<QString,QString>> _r = _t->deviceNames((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QMap<QString,QString>>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QStringList> _r = _t->devices();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QStringList> _r = _t->devices((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<QStringList> _r = _t->devices((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->forceOnNetworkChange();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<QStringList> _r = _t->linkProviders();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<QString> _r = _t->selfId();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->sendSimpleNotification((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->setAnnouncedName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->setLinkProviderState((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKdeconnectDaemonInterface::*)(const QString & )>(_a, &OrgKdeKdeconnectDaemonInterface::announcedNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKdeconnectDaemonInterface::*)(const QStringList & )>(_a, &OrgKdeKdeconnectDaemonInterface::customDevicesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKdeconnectDaemonInterface::*)(const QString & )>(_a, &OrgKdeKdeconnectDaemonInterface::deviceAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKdeconnectDaemonInterface::*)()>(_a, &OrgKdeKdeconnectDaemonInterface::deviceListChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKdeconnectDaemonInterface::*)(const QString & )>(_a, &OrgKdeKdeconnectDaemonInterface::deviceRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKdeconnectDaemonInterface::*)(const QString & , bool )>(_a, &OrgKdeKdeconnectDaemonInterface::deviceVisibilityChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKdeconnectDaemonInterface::*)(const QStringList & )>(_a, &OrgKdeKdeconnectDaemonInterface::linkProvidersChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKdeconnectDaemonInterface::*)()>(_a, &OrgKdeKdeconnectDaemonInterface::pairingRequestsChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->customDevices(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->pairingRequests(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCustomDevices(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *OrgKdeKdeconnectDaemonInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeKdeconnectDaemonInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31OrgKdeKdeconnectDaemonInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeKdeconnectDaemonInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeKdeconnectDaemonInterface::announcedNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OrgKdeKdeconnectDaemonInterface::customDevicesChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void OrgKdeKdeconnectDaemonInterface::deviceAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OrgKdeKdeconnectDaemonInterface::deviceListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void OrgKdeKdeconnectDaemonInterface::deviceRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void OrgKdeKdeconnectDaemonInterface::deviceVisibilityChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void OrgKdeKdeconnectDaemonInterface::linkProvidersChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void OrgKdeKdeconnectDaemonInterface::pairingRequestsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
