/****************************************************************************
** Meta object code from reading C++ file 'opticaldrive.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../solid-6.26.0/src/solid/devices/frontend/opticaldrive.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'opticaldrive.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Solid12OpticalDriveE_t {};
} // unnamed namespace

template <> constexpr inline auto Solid::OpticalDrive::qt_create_metaobjectdata<qt_meta_tag_ZN5Solid12OpticalDriveE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Solid::OpticalDrive",
        "ejectPressed",
        "",
        "udi",
        "ejectDone",
        "Solid::ErrorType",
        "error",
        "QVariant",
        "errorData",
        "ejectRequested",
        "supportedMedia",
        "MediumTypes",
        "readSpeed",
        "writeSpeed",
        "writeSpeeds",
        "QList<int>",
        "MediumType",
        "UnknownMediumType",
        "Cdr",
        "Cdrw",
        "Dvd",
        "Dvdr",
        "Dvdrw",
        "Dvdram",
        "Dvdplusr",
        "Dvdplusrw",
        "Dvdplusdl",
        "Dvdplusdlrw",
        "Bd",
        "Bdr",
        "Bdre",
        "HdDvd",
        "HdDvdr",
        "HdDvdrw"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ejectPressed'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ejectDone'
        QtMocHelpers::SignalData<void(Solid::ErrorType, QVariant, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { QMetaType::QString, 3 },
        }}),
        // Signal 'ejectRequested'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'supportedMedia'
        QtMocHelpers::PropertyData<MediumTypes>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'readSpeed'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'writeSpeed'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'writeSpeeds'
        QtMocHelpers::PropertyData<QList<int>>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MediumType'
        QtMocHelpers::EnumData<enum MediumType>(16, 16, QMC::EnumFlags{}).add({
            {   17, MediumType::UnknownMediumType },
            {   18, MediumType::Cdr },
            {   19, MediumType::Cdrw },
            {   20, MediumType::Dvd },
            {   21, MediumType::Dvdr },
            {   22, MediumType::Dvdrw },
            {   23, MediumType::Dvdram },
            {   24, MediumType::Dvdplusr },
            {   25, MediumType::Dvdplusrw },
            {   26, MediumType::Dvdplusdl },
            {   27, MediumType::Dvdplusdlrw },
            {   28, MediumType::Bd },
            {   29, MediumType::Bdr },
            {   30, MediumType::Bdre },
            {   31, MediumType::HdDvd },
            {   32, MediumType::HdDvdr },
            {   33, MediumType::HdDvdrw },
        }),
        // flag 'MediumTypes'
        QtMocHelpers::EnumData<MediumTypes>(11, 16, QMC::EnumIsFlag).add({
            {   17, MediumType::UnknownMediumType },
            {   18, MediumType::Cdr },
            {   19, MediumType::Cdrw },
            {   20, MediumType::Dvd },
            {   21, MediumType::Dvdr },
            {   22, MediumType::Dvdrw },
            {   23, MediumType::Dvdram },
            {   24, MediumType::Dvdplusr },
            {   25, MediumType::Dvdplusrw },
            {   26, MediumType::Dvdplusdl },
            {   27, MediumType::Dvdplusdlrw },
            {   28, MediumType::Bd },
            {   29, MediumType::Bdr },
            {   30, MediumType::Bdre },
            {   31, MediumType::HdDvd },
            {   32, MediumType::HdDvdr },
            {   33, MediumType::HdDvdrw },
        }),
    };
    return QtMocHelpers::metaObjectData<OpticalDrive, qt_meta_tag_ZN5Solid12OpticalDriveE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Solid::OpticalDrive::staticMetaObject = { {
    QMetaObject::SuperData::link<StorageDrive::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid12OpticalDriveE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid12OpticalDriveE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Solid12OpticalDriveE_t>.metaTypes,
    nullptr
} };

void Solid::OpticalDrive::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OpticalDrive *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ejectPressed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->ejectDone((*reinterpret_cast<std::add_pointer_t<Solid::ErrorType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->ejectRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Solid::ErrorType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OpticalDrive::*)(const QString & )>(_a, &OpticalDrive::ejectPressed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OpticalDrive::*)(Solid::ErrorType , QVariant , const QString & )>(_a, &OpticalDrive::ejectDone, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OpticalDrive::*)(const QString & )>(_a, &OpticalDrive::ejectRequested, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::assignFlags<MediumTypes>(_v, _t->supportedMedia()); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->readSpeed(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->writeSpeed(); break;
        case 3: *reinterpret_cast<QList<int>*>(_v) = _t->writeSpeeds(); break;
        default: break;
        }
    }
}

const QMetaObject *Solid::OpticalDrive::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Solid::OpticalDrive::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid12OpticalDriveE_t>.strings))
        return static_cast<void*>(this);
    return StorageDrive::qt_metacast(_clname);
}

int Solid::OpticalDrive::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = StorageDrive::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Solid::OpticalDrive::ejectPressed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Solid::OpticalDrive::ejectDone(Solid::ErrorType _t1, QVariant _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Solid::OpticalDrive::ejectRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
