/****************************************************************************
** Meta object code from reading C++ file 'udevqtclient.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../solid-6.26.0/src/solid/devices/backends/shared/udevqtclient.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'udevqtclient.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6UdevQt6ClientE_t {};
} // unnamed namespace

template <> constexpr inline auto UdevQt::Client::qt_create_metaobjectdata<qt_meta_tag_ZN6UdevQt6ClientE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UdevQt::Client",
        "deviceAdded",
        "",
        "UdevQt::Device",
        "dev",
        "deviceRemoved",
        "deviceChanged",
        "deviceOnlined",
        "deviceOfflined",
        "deviceBound",
        "deviceUnbound",
        "watchedSubsystems"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'deviceAdded'
        QtMocHelpers::SignalData<void(const UdevQt::Device &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(const UdevQt::Device &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deviceChanged'
        QtMocHelpers::SignalData<void(const UdevQt::Device &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deviceOnlined'
        QtMocHelpers::SignalData<void(const UdevQt::Device &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deviceOfflined'
        QtMocHelpers::SignalData<void(const UdevQt::Device &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deviceBound'
        QtMocHelpers::SignalData<void(const UdevQt::Device &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deviceUnbound'
        QtMocHelpers::SignalData<void(const UdevQt::Device &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'watchedSubsystems'
        QtMocHelpers::PropertyData<QStringList>(11, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Client, qt_meta_tag_ZN6UdevQt6ClientE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UdevQt::Client::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6UdevQt6ClientE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6UdevQt6ClientE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6UdevQt6ClientE_t>.metaTypes,
    nullptr
} };

void UdevQt::Client::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Client *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<UdevQt::Device>>(_a[1]))); break;
        case 1: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<UdevQt::Device>>(_a[1]))); break;
        case 2: _t->deviceChanged((*reinterpret_cast<std::add_pointer_t<UdevQt::Device>>(_a[1]))); break;
        case 3: _t->deviceOnlined((*reinterpret_cast<std::add_pointer_t<UdevQt::Device>>(_a[1]))); break;
        case 4: _t->deviceOfflined((*reinterpret_cast<std::add_pointer_t<UdevQt::Device>>(_a[1]))); break;
        case 5: _t->deviceBound((*reinterpret_cast<std::add_pointer_t<UdevQt::Device>>(_a[1]))); break;
        case 6: _t->deviceUnbound((*reinterpret_cast<std::add_pointer_t<UdevQt::Device>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Client::*)(const UdevQt::Device & )>(_a, &Client::deviceAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Client::*)(const UdevQt::Device & )>(_a, &Client::deviceRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Client::*)(const UdevQt::Device & )>(_a, &Client::deviceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Client::*)(const UdevQt::Device & )>(_a, &Client::deviceOnlined, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Client::*)(const UdevQt::Device & )>(_a, &Client::deviceOfflined, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Client::*)(const UdevQt::Device & )>(_a, &Client::deviceBound, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Client::*)(const UdevQt::Device & )>(_a, &Client::deviceUnbound, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->watchedSubsystems(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWatchedSubsystems(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *UdevQt::Client::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UdevQt::Client::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6UdevQt6ClientE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UdevQt::Client::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void UdevQt::Client::deviceAdded(const UdevQt::Device & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void UdevQt::Client::deviceRemoved(const UdevQt::Device & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void UdevQt::Client::deviceChanged(const UdevQt::Device & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void UdevQt::Client::deviceOnlined(const UdevQt::Device & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void UdevQt::Client::deviceOfflined(const UdevQt::Device & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void UdevQt::Client::deviceBound(const UdevQt::Device & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void UdevQt::Client::deviceUnbound(const UdevQt::Device & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
