/****************************************************************************
** Meta object code from reading C++ file 'udisksopticaldrive.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../solid-6.26.0/src/solid/devices/backends/udisks2/udisksopticaldrive.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'udisksopticaldrive.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Solid8Backends7UDisks212OpticalDriveE_t {};
} // unnamed namespace

template <> constexpr inline auto Solid::Backends::UDisks2::OpticalDrive::qt_create_metaobjectdata<qt_meta_tag_ZN5Solid8Backends7UDisks212OpticalDriveE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Solid::Backends::UDisks2::OpticalDrive",
        "ejectPressed",
        "",
        "udi",
        "ejectDone",
        "Solid::ErrorType",
        "error",
        "QVariant",
        "errorData",
        "ejectRequested",
        "slotDBusReply",
        "QDBusMessage",
        "reply",
        "slotDBusError",
        "QDBusError",
        "slotEjectRequested",
        "slotEjectDone",
        "errorString",
        "slotChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ejectPressed'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ejectDone'
        QtMocHelpers::SignalData<void(Solid::ErrorType, QVariant, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { QMetaType::QString, 3 },
        }}),
        // Signal 'ejectRequested'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'slotDBusReply'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'slotDBusError'
        QtMocHelpers::SlotData<void(const QDBusError &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 6 },
        }}),
        // Slot 'slotEjectRequested'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEjectDone'
        QtMocHelpers::SlotData<void(int, const QString &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'slotChanged'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OpticalDrive, qt_meta_tag_ZN5Solid8Backends7UDisks212OpticalDriveE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Solid::Backends::UDisks2::OpticalDrive::staticMetaObject = { {
    QMetaObject::SuperData::link<StorageDrive::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends7UDisks212OpticalDriveE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends7UDisks212OpticalDriveE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Solid8Backends7UDisks212OpticalDriveE_t>.metaTypes,
    nullptr
} };

void Solid::Backends::UDisks2::OpticalDrive::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OpticalDrive *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ejectPressed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->ejectDone((*reinterpret_cast<std::add_pointer_t<Solid::ErrorType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->ejectRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->slotDBusReply((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 4: _t->slotDBusError((*reinterpret_cast<std::add_pointer_t<QDBusError>>(_a[1]))); break;
        case 5: _t->slotEjectRequested(); break;
        case 6: _t->slotEjectDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->slotChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Solid::ErrorType >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OpticalDrive::*)(const QString & )>(_a, &OpticalDrive::ejectPressed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OpticalDrive::*)(Solid::ErrorType , QVariant , const QString & )>(_a, &OpticalDrive::ejectDone, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OpticalDrive::*)(const QString & )>(_a, &OpticalDrive::ejectRequested, 2))
            return;
    }
}

const QMetaObject *Solid::Backends::UDisks2::OpticalDrive::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Solid::Backends::UDisks2::OpticalDrive::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends7UDisks212OpticalDriveE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Solid::Ifaces::OpticalDrive"))
        return static_cast< Solid::Ifaces::OpticalDrive*>(this);
    if (!strcmp(_clname, "org.kde.Solid.Ifaces.OpticalDrive/0.1"))
        return static_cast< Solid::Ifaces::OpticalDrive*>(this);
    return StorageDrive::qt_metacast(_clname);
}

int Solid::Backends::UDisks2::OpticalDrive::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = StorageDrive::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Solid::Backends::UDisks2::OpticalDrive::ejectPressed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Solid::Backends::UDisks2::OpticalDrive::ejectDone(Solid::ErrorType _t1, QVariant _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Solid::Backends::UDisks2::OpticalDrive::ejectRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
