/****************************************************************************
** Meta object code from reading C++ file 'fakeopticaldisc.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../solid-6.26.0/src/solid/devices/backends/fakehw/fakeopticaldisc.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fakeopticaldisc.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Solid8Backends4Fake15FakeOpticalDiscE_t {};
} // unnamed namespace

template <> constexpr inline auto Solid::Backends::Fake::FakeOpticalDisc::qt_create_metaobjectdata<qt_meta_tag_ZN5Solid8Backends4Fake15FakeOpticalDiscE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Solid::Backends::Fake::FakeOpticalDisc",
        "availableContent",
        "Solid::OpticalDisc::ContentTypes",
        "",
        "discType",
        "Solid::OpticalDisc::DiscType",
        "isAppendable",
        "isBlank",
        "isRewritable",
        "capacity"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'availableContent'
        QtMocHelpers::SlotData<Solid::OpticalDisc::ContentTypes() const>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'discType'
        QtMocHelpers::SlotData<Solid::OpticalDisc::DiscType() const>(4, 3, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'isAppendable'
        QtMocHelpers::SlotData<bool() const>(6, 3, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isBlank'
        QtMocHelpers::SlotData<bool() const>(7, 3, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isRewritable'
        QtMocHelpers::SlotData<bool() const>(8, 3, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'capacity'
        QtMocHelpers::SlotData<qulonglong() const>(9, 3, QMC::AccessPublic, QMetaType::ULongLong),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FakeOpticalDisc, qt_meta_tag_ZN5Solid8Backends4Fake15FakeOpticalDiscE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Solid::Backends::Fake::FakeOpticalDisc::staticMetaObject = { {
    QMetaObject::SuperData::link<FakeVolume::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends4Fake15FakeOpticalDiscE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends4Fake15FakeOpticalDiscE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Solid8Backends4Fake15FakeOpticalDiscE_t>.metaTypes,
    nullptr
} };

void Solid::Backends::Fake::FakeOpticalDisc::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FakeOpticalDisc *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { Solid::OpticalDisc::ContentTypes _r = _t->availableContent();
            if (_a[0]) *reinterpret_cast<Solid::OpticalDisc::ContentTypes*>(_a[0]) = std::move(_r); }  break;
        case 1: { Solid::OpticalDisc::DiscType _r = _t->discType();
            if (_a[0]) *reinterpret_cast<Solid::OpticalDisc::DiscType*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->isAppendable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->isBlank();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->isRewritable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { qulonglong _r = _t->capacity();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Solid::Backends::Fake::FakeOpticalDisc::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Solid::Backends::Fake::FakeOpticalDisc::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends4Fake15FakeOpticalDiscE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Solid::Ifaces::OpticalDisc"))
        return static_cast< Solid::Ifaces::OpticalDisc*>(this);
    if (!strcmp(_clname, "org.kde.Solid.Ifaces.OpticalDisc/0.1"))
        return static_cast< Solid::Ifaces::OpticalDisc*>(this);
    return FakeVolume::qt_metacast(_clname);
}

int Solid::Backends::Fake::FakeOpticalDisc::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = FakeVolume::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
