/****************************************************************************
** Meta object code from reading C++ file 'processor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../solid-6.26.0/src/solid/devices/frontend/processor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'processor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Solid9ProcessorE_t {};
} // unnamed namespace

template <> constexpr inline auto Solid::Processor::qt_create_metaobjectdata<qt_meta_tag_ZN5Solid9ProcessorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Solid::Processor",
        "number",
        "maxSpeed",
        "canChangeFrequency",
        "instructionSets",
        "InstructionSets",
        "InstructionSet",
        "NoExtensions",
        "IntelMmx",
        "IntelSse",
        "IntelSse2",
        "IntelSse3",
        "IntelSsse3",
        "IntelSse4",
        "IntelSse41",
        "IntelSse42",
        "Amd3DNow",
        "AltiVec"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'number'
        QtMocHelpers::PropertyData<int>(1, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'maxSpeed'
        QtMocHelpers::PropertyData<qulonglong>(2, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'canChangeFrequency'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'instructionSets'
        QtMocHelpers::PropertyData<InstructionSets>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'InstructionSet'
        QtMocHelpers::EnumData<enum InstructionSet>(6, 6, QMC::EnumFlags{}).add({
            {    7, InstructionSet::NoExtensions },
            {    8, InstructionSet::IntelMmx },
            {    9, InstructionSet::IntelSse },
            {   10, InstructionSet::IntelSse2 },
            {   11, InstructionSet::IntelSse3 },
            {   12, InstructionSet::IntelSsse3 },
            {   13, InstructionSet::IntelSse4 },
            {   14, InstructionSet::IntelSse41 },
            {   15, InstructionSet::IntelSse42 },
            {   16, InstructionSet::Amd3DNow },
            {   17, InstructionSet::AltiVec },
        }),
        // flag 'InstructionSets'
        QtMocHelpers::EnumData<InstructionSets>(5, 6, QMC::EnumIsFlag).add({
            {    7, InstructionSet::NoExtensions },
            {    8, InstructionSet::IntelMmx },
            {    9, InstructionSet::IntelSse },
            {   10, InstructionSet::IntelSse2 },
            {   11, InstructionSet::IntelSse3 },
            {   12, InstructionSet::IntelSsse3 },
            {   13, InstructionSet::IntelSse4 },
            {   14, InstructionSet::IntelSse41 },
            {   15, InstructionSet::IntelSse42 },
            {   16, InstructionSet::Amd3DNow },
            {   17, InstructionSet::AltiVec },
        }),
    };
    return QtMocHelpers::metaObjectData<Processor, qt_meta_tag_ZN5Solid9ProcessorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Solid::Processor::staticMetaObject = { {
    QMetaObject::SuperData::link<DeviceInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid9ProcessorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid9ProcessorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Solid9ProcessorE_t>.metaTypes,
    nullptr
} };

void Solid::Processor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Processor *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->number(); break;
        case 1: *reinterpret_cast<qulonglong*>(_v) = _t->maxSpeed(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canChangeFrequency(); break;
        case 3: QtMocHelpers::assignFlags<InstructionSets>(_v, _t->instructionSets()); break;
        default: break;
        }
    }
}

const QMetaObject *Solid::Processor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Solid::Processor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid9ProcessorE_t>.strings))
        return static_cast<void*>(this);
    return DeviceInterface::qt_metacast(_clname);
}

int Solid::Processor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DeviceInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
