// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "devices_debug.h"

 namespace Solid { namespace Frontend { namespace DeviceManager {
Q_LOGGING_CATEGORY(DEVICEMANAGER, "kf.solid.frontend.devicemanager", QtWarningMsg)
} } } 
