/****************************************************************************
** Meta object code from reading C++ file 'opticaldisc.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../solid-6.26.0/src/solid/devices/frontend/opticaldisc.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'opticaldisc.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Solid11OpticalDiscE_t {};
} // unnamed namespace

template <> constexpr inline auto Solid::OpticalDisc::qt_create_metaobjectdata<qt_meta_tag_ZN5Solid11OpticalDiscE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Solid::OpticalDisc",
        "availableContent",
        "ContentTypes",
        "discType",
        "DiscType",
        "appendable",
        "blank",
        "rewritable",
        "capacity",
        "ContentType",
        "NoContent",
        "Audio",
        "Data",
        "VideoCd",
        "SuperVideoCd",
        "VideoDvd",
        "VideoBluRay",
        "UnknownDiscType",
        "CdRom",
        "CdRecordable",
        "CdRewritable",
        "DvdRom",
        "DvdRam",
        "DvdRecordable",
        "DvdRewritable",
        "DvdPlusRecordable",
        "DvdPlusRewritable",
        "DvdPlusRecordableDuallayer",
        "DvdPlusRewritableDuallayer",
        "BluRayRom",
        "BluRayRecordable",
        "BluRayRewritable",
        "HdDvdRom",
        "HdDvdRecordable",
        "HdDvdRewritable"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'availableContent'
        QtMocHelpers::PropertyData<ContentTypes>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'discType'
        QtMocHelpers::PropertyData<enum DiscType>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'appendable'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'blank'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'rewritable'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'capacity'
        QtMocHelpers::PropertyData<qulonglong>(8, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ContentType'
        QtMocHelpers::EnumData<enum ContentType>(9, 9, QMC::EnumFlags{}).add({
            {   10, ContentType::NoContent },
            {   11, ContentType::Audio },
            {   12, ContentType::Data },
            {   13, ContentType::VideoCd },
            {   14, ContentType::SuperVideoCd },
            {   15, ContentType::VideoDvd },
            {   16, ContentType::VideoBluRay },
        }),
        // flag 'ContentTypes'
        QtMocHelpers::EnumData<ContentTypes>(2, 9, QMC::EnumIsFlag).add({
            {   10, ContentType::NoContent },
            {   11, ContentType::Audio },
            {   12, ContentType::Data },
            {   13, ContentType::VideoCd },
            {   14, ContentType::SuperVideoCd },
            {   15, ContentType::VideoDvd },
            {   16, ContentType::VideoBluRay },
        }),
        // enum 'DiscType'
        QtMocHelpers::EnumData<enum DiscType>(4, 4, QMC::EnumFlags{}).add({
            {   17, DiscType::UnknownDiscType },
            {   18, DiscType::CdRom },
            {   19, DiscType::CdRecordable },
            {   20, DiscType::CdRewritable },
            {   21, DiscType::DvdRom },
            {   22, DiscType::DvdRam },
            {   23, DiscType::DvdRecordable },
            {   24, DiscType::DvdRewritable },
            {   25, DiscType::DvdPlusRecordable },
            {   26, DiscType::DvdPlusRewritable },
            {   27, DiscType::DvdPlusRecordableDuallayer },
            {   28, DiscType::DvdPlusRewritableDuallayer },
            {   29, DiscType::BluRayRom },
            {   30, DiscType::BluRayRecordable },
            {   31, DiscType::BluRayRewritable },
            {   32, DiscType::HdDvdRom },
            {   33, DiscType::HdDvdRecordable },
            {   34, DiscType::HdDvdRewritable },
        }),
    };
    return QtMocHelpers::metaObjectData<OpticalDisc, qt_meta_tag_ZN5Solid11OpticalDiscE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Solid::OpticalDisc::staticMetaObject = { {
    QMetaObject::SuperData::link<StorageVolume::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid11OpticalDiscE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid11OpticalDiscE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Solid11OpticalDiscE_t>.metaTypes,
    nullptr
} };

void Solid::OpticalDisc::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OpticalDisc *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::assignFlags<ContentTypes>(_v, _t->availableContent()); break;
        case 1: *reinterpret_cast<enum DiscType*>(_v) = _t->discType(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isAppendable(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isBlank(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isRewritable(); break;
        case 5: *reinterpret_cast<qulonglong*>(_v) = _t->capacity(); break;
        default: break;
        }
    }
}

const QMetaObject *Solid::OpticalDisc::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Solid::OpticalDisc::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid11OpticalDiscE_t>.strings))
        return static_cast<void*>(this);
    return StorageVolume::qt_metacast(_clname);
}

int Solid::OpticalDisc::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = StorageVolume::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
