/****************************************************************************
** Meta object code from reading C++ file 'fakecdrom.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../solid-6.26.0/src/solid/devices/backends/fakehw/fakecdrom.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fakecdrom.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Solid8Backends4Fake9FakeCdromE_t {};
} // unnamed namespace

template <> constexpr inline auto Solid::Backends::Fake::FakeCdrom::qt_create_metaobjectdata<qt_meta_tag_ZN5Solid8Backends4Fake9FakeCdromE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Solid::Backends::Fake::FakeCdrom",
        "ejectPressed",
        "",
        "udi",
        "ejectDone",
        "Solid::ErrorType",
        "error",
        "QVariant",
        "errorData",
        "ejectRequested",
        "supportedMedia",
        "Solid::OpticalDrive::MediumTypes",
        "readSpeed",
        "writeSpeed",
        "writeSpeeds",
        "QList<int>",
        "eject"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ejectPressed'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ejectDone'
        QtMocHelpers::SignalData<void(Solid::ErrorType, QVariant, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { QMetaType::QString, 3 },
        }}),
        // Signal 'ejectRequested'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'supportedMedia'
        QtMocHelpers::SlotData<Solid::OpticalDrive::MediumTypes() const>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'readSpeed'
        QtMocHelpers::SlotData<int() const>(12, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'writeSpeed'
        QtMocHelpers::SlotData<int() const>(13, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'writeSpeeds'
        QtMocHelpers::SlotData<QList<int>() const>(14, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'eject'
        QtMocHelpers::SlotData<bool()>(16, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FakeCdrom, qt_meta_tag_ZN5Solid8Backends4Fake9FakeCdromE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Solid::Backends::Fake::FakeCdrom::staticMetaObject = { {
    QMetaObject::SuperData::link<FakeStorage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends4Fake9FakeCdromE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends4Fake9FakeCdromE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Solid8Backends4Fake9FakeCdromE_t>.metaTypes,
    nullptr
} };

void Solid::Backends::Fake::FakeCdrom::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FakeCdrom *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ejectPressed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->ejectDone((*reinterpret_cast<std::add_pointer_t<Solid::ErrorType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->ejectRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: { Solid::OpticalDrive::MediumTypes _r = _t->supportedMedia();
            if (_a[0]) *reinterpret_cast<Solid::OpticalDrive::MediumTypes*>(_a[0]) = std::move(_r); }  break;
        case 4: { int _r = _t->readSpeed();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->writeSpeed();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: { QList<int> _r = _t->writeSpeeds();
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->eject();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Solid::ErrorType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FakeCdrom::*)(const QString & )>(_a, &FakeCdrom::ejectPressed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FakeCdrom::*)(Solid::ErrorType , QVariant , const QString & )>(_a, &FakeCdrom::ejectDone, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FakeCdrom::*)(const QString & )>(_a, &FakeCdrom::ejectRequested, 2))
            return;
    }
}

const QMetaObject *Solid::Backends::Fake::FakeCdrom::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Solid::Backends::Fake::FakeCdrom::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends4Fake9FakeCdromE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Solid::Ifaces::OpticalDrive"))
        return static_cast< Solid::Ifaces::OpticalDrive*>(this);
    if (!strcmp(_clname, "org.kde.Solid.Ifaces.OpticalDrive/0.1"))
        return static_cast< Solid::Ifaces::OpticalDrive*>(this);
    return FakeStorage::qt_metacast(_clname);
}

int Solid::Backends::Fake::FakeCdrom::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = FakeStorage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Solid::Backends::Fake::FakeCdrom::ejectPressed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Solid::Backends::Fake::FakeCdrom::ejectDone(Solid::ErrorType _t1, QVariant _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Solid::Backends::Fake::FakeCdrom::ejectRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
