/****************************************************************************
** Meta object code from reading C++ file 'fstabstorageaccess.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../solid-6.26.0/src/solid/devices/backends/fstab/fstabstorageaccess.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fstabstorageaccess.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Solid8Backends5Fstab18FstabStorageAccessE_t {};
} // unnamed namespace

template <> constexpr inline auto Solid::Backends::Fstab::FstabStorageAccess::qt_create_metaobjectdata<qt_meta_tag_ZN5Solid8Backends5Fstab18FstabStorageAccessE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Solid::Backends::Fstab::FstabStorageAccess",
        "accessibilityChanged",
        "",
        "accessible",
        "udi",
        "setupDone",
        "Solid::ErrorType",
        "error",
        "QVariant",
        "data",
        "teardownDone",
        "setupRequested",
        "teardownRequested",
        "checkRequested",
        "checkDone",
        "errorData",
        "repairRequested",
        "repairDone",
        "resultData",
        "onMtabChanged",
        "device",
        "connectDBusSignals",
        "slotSetupRequested",
        "slotSetupDone",
        "errorString",
        "slotTeardownRequested",
        "slotTeardownDone"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accessibilityChanged'
        QtMocHelpers::SignalData<void(bool, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'setupDone'
        QtMocHelpers::SignalData<void(Solid::ErrorType, QVariant, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'teardownDone'
        QtMocHelpers::SignalData<void(Solid::ErrorType, QVariant, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'setupRequested'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'teardownRequested'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'checkRequested'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'checkDone'
        QtMocHelpers::SignalData<void(Solid::ErrorType, QVariant, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 15 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'repairRequested'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'repairDone'
        QtMocHelpers::SignalData<void(Solid::ErrorType, QVariant, const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 18 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'onMtabChanged'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'connectDBusSignals'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetupRequested'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetupDone'
        QtMocHelpers::SlotData<void(int, const QString &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'slotTeardownRequested'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTeardownDone'
        QtMocHelpers::SlotData<void(int, const QString &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::QString, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FstabStorageAccess, qt_meta_tag_ZN5Solid8Backends5Fstab18FstabStorageAccessE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Solid::Backends::Fstab::FstabStorageAccess::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends5Fstab18FstabStorageAccessE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends5Fstab18FstabStorageAccessE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Solid8Backends5Fstab18FstabStorageAccessE_t>.metaTypes,
    nullptr
} };

void Solid::Backends::Fstab::FstabStorageAccess::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FstabStorageAccess *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accessibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->setupDone((*reinterpret_cast<std::add_pointer_t<Solid::ErrorType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->teardownDone((*reinterpret_cast<std::add_pointer_t<Solid::ErrorType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 3: _t->setupRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->teardownRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->checkRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->checkDone((*reinterpret_cast<std::add_pointer_t<Solid::ErrorType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->repairRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->repairDone((*reinterpret_cast<std::add_pointer_t<Solid::ErrorType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 9: _t->onMtabChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->connectDBusSignals(); break;
        case 11: _t->slotSetupRequested(); break;
        case 12: _t->slotSetupDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->slotTeardownRequested(); break;
        case 14: _t->slotTeardownDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Solid::ErrorType >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Solid::ErrorType >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Solid::ErrorType >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Solid::ErrorType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FstabStorageAccess::*)(bool , const QString & )>(_a, &FstabStorageAccess::accessibilityChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FstabStorageAccess::*)(Solid::ErrorType , QVariant , const QString & )>(_a, &FstabStorageAccess::setupDone, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FstabStorageAccess::*)(Solid::ErrorType , QVariant , const QString & )>(_a, &FstabStorageAccess::teardownDone, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FstabStorageAccess::*)(const QString & )>(_a, &FstabStorageAccess::setupRequested, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FstabStorageAccess::*)(const QString & )>(_a, &FstabStorageAccess::teardownRequested, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FstabStorageAccess::*)(const QString & )>(_a, &FstabStorageAccess::checkRequested, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FstabStorageAccess::*)(Solid::ErrorType , QVariant , const QString & )>(_a, &FstabStorageAccess::checkDone, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FstabStorageAccess::*)(const QString & )>(_a, &FstabStorageAccess::repairRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FstabStorageAccess::*)(Solid::ErrorType , QVariant , const QString & )>(_a, &FstabStorageAccess::repairDone, 8))
            return;
    }
}

const QMetaObject *Solid::Backends::Fstab::FstabStorageAccess::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Solid::Backends::Fstab::FstabStorageAccess::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid8Backends5Fstab18FstabStorageAccessE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Solid::Ifaces::StorageAccess"))
        return static_cast< Solid::Ifaces::StorageAccess*>(this);
    if (!strcmp(_clname, "org.kde.Solid.Ifaces.StorageAccess/0.1"))
        return static_cast< Solid::Ifaces::StorageAccess*>(this);
    return QObject::qt_metacast(_clname);
}

int Solid::Backends::Fstab::FstabStorageAccess::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Solid::Backends::Fstab::FstabStorageAccess::accessibilityChanged(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Solid::Backends::Fstab::FstabStorageAccess::setupDone(Solid::ErrorType _t1, QVariant _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void Solid::Backends::Fstab::FstabStorageAccess::teardownDone(Solid::ErrorType _t1, QVariant _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void Solid::Backends::Fstab::FstabStorageAccess::setupRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Solid::Backends::Fstab::FstabStorageAccess::teardownRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Solid::Backends::Fstab::FstabStorageAccess::checkRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Solid::Backends::Fstab::FstabStorageAccess::checkDone(Solid::ErrorType _t1, QVariant _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void Solid::Backends::Fstab::FstabStorageAccess::repairRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Solid::Backends::Fstab::FstabStorageAccess::repairDone(Solid::ErrorType _t1, QVariant _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
