// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "kdeconnect_debug.h"

 namespace Solid { namespace Backends { namespace KdeConnect {
Q_LOGGING_CATEGORY(KDECONNECT, "kf.solid.backends.kdeconnect", QtWarningMsg)
} } } 
