/****************************************************************************
** Meta object code from reading C++ file 'storagedrive.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../solid-6.26.0/src/solid/devices/frontend/storagedrive.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'storagedrive.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Solid12StorageDriveE_t {};
} // unnamed namespace

template <> constexpr inline auto Solid::StorageDrive::qt_create_metaobjectdata<qt_meta_tag_ZN5Solid12StorageDriveE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Solid::StorageDrive",
        "bus",
        "Bus",
        "driveType",
        "DriveType",
        "removable",
        "hotpluggable",
        "inUse",
        "size",
        "timeDetected",
        "timeMediaDetected",
        "Ide",
        "Usb",
        "Ieee1394",
        "Scsi",
        "Sata",
        "Platform",
        "HardDisk",
        "CdromDrive",
        "Floppy",
        "Tape",
        "CompactFlash",
        "MemoryStick",
        "SmartMedia",
        "SdMmc",
        "Xd"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bus'
        QtMocHelpers::PropertyData<enum Bus>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'driveType'
        QtMocHelpers::PropertyData<enum DriveType>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'removable'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'hotpluggable'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'inUse'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'size'
        QtMocHelpers::PropertyData<qulonglong>(8, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'timeDetected'
        QtMocHelpers::PropertyData<QDateTime>(9, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'timeMediaDetected'
        QtMocHelpers::PropertyData<QDateTime>(10, QMetaType::QDateTime, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Bus'
        QtMocHelpers::EnumData<enum Bus>(2, 2, QMC::EnumFlags{}).add({
            {   11, Bus::Ide },
            {   12, Bus::Usb },
            {   13, Bus::Ieee1394 },
            {   14, Bus::Scsi },
            {   15, Bus::Sata },
            {   16, Bus::Platform },
        }),
        // enum 'DriveType'
        QtMocHelpers::EnumData<enum DriveType>(4, 4, QMC::EnumFlags{}).add({
            {   17, DriveType::HardDisk },
            {   18, DriveType::CdromDrive },
            {   19, DriveType::Floppy },
            {   20, DriveType::Tape },
            {   21, DriveType::CompactFlash },
            {   22, DriveType::MemoryStick },
            {   23, DriveType::SmartMedia },
            {   24, DriveType::SdMmc },
            {   25, DriveType::Xd },
        }),
    };
    return QtMocHelpers::metaObjectData<StorageDrive, qt_meta_tag_ZN5Solid12StorageDriveE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Solid::StorageDrive::staticMetaObject = { {
    QMetaObject::SuperData::link<DeviceInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid12StorageDriveE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid12StorageDriveE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Solid12StorageDriveE_t>.metaTypes,
    nullptr
} };

void Solid::StorageDrive::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StorageDrive *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Bus*>(_v) = _t->bus(); break;
        case 1: *reinterpret_cast<enum DriveType*>(_v) = _t->driveType(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isRemovable(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isHotpluggable(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInUse(); break;
        case 5: *reinterpret_cast<qulonglong*>(_v) = _t->size(); break;
        case 6: *reinterpret_cast<QDateTime*>(_v) = _t->timeDetected(); break;
        case 7: *reinterpret_cast<QDateTime*>(_v) = _t->timeDetected(); break;
        default: break;
        }
    }
}

const QMetaObject *Solid::StorageDrive::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Solid::StorageDrive::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Solid12StorageDriveE_t>.strings))
        return static_cast<void*>(this);
    return DeviceInterface::qt_metacast(_clname);
}

int Solid::StorageDrive::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DeviceInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
