// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "fstab_debug.h"

 namespace Solid { namespace Backends { namespace Fstab {
Q_LOGGING_CATEGORY(FSTAB_LOG, "kf.solid.backends.fstab", QtWarningMsg)
} } } 
